/*!
 * All Studio Web Components
 * Copyright (c) Halfcute Internet Pvt Ltd
 */
import { Host, h } from '@stencil/core';
export class AsProductCard {
  constructor() {
    this.theme = 'dark';
    this.quickcart = 0;
    this.imagesize = 'small';
    this.product = undefined;
    this.mode = 'shopnow';
    this.overlay = undefined;
    this.channel = undefined;
    this.trackevent = null;
    this.player = undefined;
    this.photoviewer = undefined;
    this.index = 0;
  }
  componentWillLoad() {
    if (this.channel) {
      this.theme = this.channel.productTheme;
      this.quickcart = this.channel.quickCart;
      this.imagesize = this.channel.productImageSize;
    }
  }
  componentDidLoad() {
    if (this.channel) {
      var style = document.createElement('style');
      style.innerHTML = `.product-card { --as-player-btn-color: ${this.channel.primaryColor.hex}; --as-player-btn-txt-color: ${this.channel.textColor.hex}; }`;
      this.el.shadowRoot.appendChild(style);
    }
    // console.log('product cart loaded', this.theme, this.quickcart, this.imagesize);
  }
  render() {
    if (this.product && this.product.id) {
      return (h(Host, null, h("a", { class: {
          "product-card": true,
          "dark": (this.theme === 'dark'),
          "light": (this.theme === 'light'),
          "image-small": (this.imagesize === "small"),
        }, href: !this.quickcart ? this.product.platformProduct.onlineStoreUrl : '#', onClick: (e) => {
          e.preventDefault();
          this.trackevent('product_card_click', {
            productid: this.product.id,
            cardindex: this.index,
            quickcart: this.quickcart,
          }, this.player || this.photoviewer);
          if (this.quickcart) {
            this.openDetails();
          }
          else {
            window.location.href = this.product.platformProduct.onlineStoreUrl;
          }
          return true;
        } }, h("img", { class: "product", src: this.product.platformProduct.featuredImage.url, alt: this.product.platformProduct.title }), h("div", { class: "product-card-body" }, h("div", { class: "product-card-item-name" }, this.product.platformProduct.title), h("div", { class: "product-card-item-price" }, h("span", { class: "unit-price-label" }, this.getPrice(this.product.platformProduct.priceRangeV2))), h("div", { class: "ctacontainer" }, h("button", { tabindex: "0", class: "product-buy-now-button" }, "Shop Now"))))));
    }
    else {
      return (h(Host, null));
    }
  }
  getPrice(range) {
    let finalPrice = `${this.getCurrencySymbol(range.minVariantPrice.currencyCode)} ${range.minVariantPrice.amount}`;
    if (range.minVariantPrice.amount !== range.maxVariantPrice.amount) {
      finalPrice = `${this.getCurrencySymbol(range.minVariantPrice.currencyCode)} ${range.minVariantPrice.amount} - ${this.getCurrencySymbol(range.minVariantPrice.currencyCode)} ${range.maxVariantPrice.amount}`;
    }
    return finalPrice;
  }
  getCurrencySymbol(currency) {
    var currency_symbols = {
      'USD': '$',
      'EUR': '€',
      'CRC': '₡',
      'GBP': '£',
      'ILS': '₪',
      'INR': '₹',
      'JPY': '¥',
      'KRW': '₩',
      'NGN': '₦',
      'PHP': '₱',
      'PLN': 'zł',
      'PYG': '₲',
      'THB': '฿',
      'UAH': '₴',
      'VND': '₫', // Vietnamese Dong
    };
    if (currency_symbols[currency] !== undefined) {
      return currency_symbols[currency];
    }
  }
  openDetails() {
    var _a;
    // console.log('open overlay from product card');
    // this.player?.viewFullScreen();
    (_a = this.overlay) === null || _a === void 0 ? void 0 : _a.open(this.product, this.channel, this.player, this.photoviewer, this.trackevent);
  }
  closeDetails() {
    this.el.shadowRoot.getElementById('product-details-popup').style.height = "0%";
  }
  static get is() { return "as-product-card"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() {
    return {
      "$": ["as-product-card.css"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["as-product-card.css"]
    };
  }
  static get properties() {
    return {
      "product": {
        "type": "any",
        "mutable": false,
        "complexType": {
          "original": "any",
          "resolved": "any",
          "references": {}
        },
        "required": false,
        "optional": true,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "product",
        "reflect": false
      },
      "mode": {
        "type": "any",
        "mutable": false,
        "complexType": {
          "original": "any",
          "resolved": "any",
          "references": {}
        },
        "required": false,
        "optional": true,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "mode",
        "reflect": false,
        "defaultValue": "'shopnow'"
      },
      "overlay": {
        "type": "any",
        "mutable": false,
        "complexType": {
          "original": "any",
          "resolved": "any",
          "references": {}
        },
        "required": false,
        "optional": true,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "overlay",
        "reflect": false
      },
      "channel": {
        "type": "any",
        "mutable": false,
        "complexType": {
          "original": "any",
          "resolved": "any",
          "references": {}
        },
        "required": false,
        "optional": true,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "channel",
        "reflect": false
      },
      "trackevent": {
        "type": "any",
        "mutable": false,
        "complexType": {
          "original": "any",
          "resolved": "any",
          "references": {}
        },
        "required": false,
        "optional": true,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "trackevent",
        "reflect": false,
        "defaultValue": "null"
      },
      "player": {
        "type": "any",
        "mutable": false,
        "complexType": {
          "original": "any",
          "resolved": "any",
          "references": {}
        },
        "required": false,
        "optional": true,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "player",
        "reflect": false
      },
      "photoviewer": {
        "type": "any",
        "mutable": false,
        "complexType": {
          "original": "any",
          "resolved": "any",
          "references": {}
        },
        "required": false,
        "optional": true,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "photoviewer",
        "reflect": false
      },
      "index": {
        "type": "number",
        "mutable": false,
        "complexType": {
          "original": "number",
          "resolved": "number",
          "references": {}
        },
        "required": false,
        "optional": true,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "index",
        "reflect": false,
        "defaultValue": "0"
      }
    };
  }
  static get elementRef() { return "el"; }
}
//# sourceMappingURL=as-product-card.js.map
