/*!
 * All Studio Web Components
 * Copyright (c) Halfcute Internet Pvt Ltd
 */
import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';

const asProductCardCss = ":host{display:block;width:272px}.product-card{color:#fff;display:flex;width:272px;height:104px;background:rgba(0,0,0,0.65);border-radius:8px;-webkit-text-decoration:none!important;text-decoration:none!important;padding:8px;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;-webkit-box-sizing:border-box;box-sizing:border-box}.product-card img.product{width:88px;height:88px;border-radius:4px;-webkit-border-radius:4px;-moz-border-radius:4px;-o-border-radius:4px;aspect-ratio:1;-o-object-fit:cover;object-fit:cover;display:block}.product-card-body{font-style:normal;padding-top:2px;padding-bottom:4px;-webkit-padding-end:0;padding-inline-end:0;-webkit-padding-start:8px;padding-inline-start:8px;text-align:left}.product-card-item-name{font-size:16px;white-space:nowrap;width:160px;overflow:hidden;text-overflow:ellipsis;line-height:18px;font-weight:400;margin-bottom:2px}.product-card-item-price{font-size:14px;line-height:16px;font-weight:500;font-family:\"Helvetica Neue\",\"Segoe UI\",Helvetica,Arial,sans-serif}.ctacontainer{line-height:16px;margin-top:10px;-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;font-size:15px;font-weight:600;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-box-sizing:border-box;box-sizing:border-box}.ctacontainer button:not(:disabled){cursor:pointer}.ctacontainer button{color:var(--as-player-btn-txt-color, #fff);-webkit-text-decoration:none;text-decoration:none;-webkit-tap-highlight-color:transparent;background:var(--as-player-btn-color, #000);border-radius:4px;-webkit-border-radius:4px;-moz-border-radius:4px;text-align:center;width:160px;line-height:40px}.product-buy-now-button{border:none;background:none;font-size:inherit;font-family:inherit;text-align:inherit;color:inherit;display:inline-block;padding:0;margin:0;-webkit-box-sizing:border-box;box-sizing:border-box}.buy-now-arrow{height:12px;-webkit-box-sizing:border-box;box-sizing:border-box}";

const AsProductCard = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.theme = 'dark';
    this.quickcart = 0;
    this.imagesize = 'small';
    this.product = undefined;
    this.mode = 'shopnow';
    this.overlay = undefined;
    this.channel = undefined;
    this.trackevent = null;
    this.player = undefined;
    this.photoviewer = undefined;
    this.index = 0;
  }
  componentWillLoad() {
    if (this.channel) {
      this.theme = this.channel.productTheme;
      this.quickcart = this.channel.quickCart;
      this.imagesize = this.channel.productImageSize;
    }
  }
  componentDidLoad() {
    if (this.channel) {
      var style = document.createElement('style');
      style.innerHTML = `.product-card { --as-player-btn-color: ${this.channel.primaryColor.hex}; --as-player-btn-txt-color: ${this.channel.textColor.hex}; }`;
      this.el.shadowRoot.appendChild(style);
    }
    // console.log('product cart loaded', this.theme, this.quickcart, this.imagesize);
  }
  render() {
    if (this.product && this.product.id) {
      return (h(Host, null, h("a", { class: {
          "product-card": true,
          "dark": (this.theme === 'dark'),
          "light": (this.theme === 'light'),
          "image-small": (this.imagesize === "small"),
        }, href: !this.quickcart ? this.product.platformProduct.onlineStoreUrl : '#', onClick: (e) => {
          e.preventDefault();
          this.trackevent('product_card_click', {
            productid: this.product.id,
            cardindex: this.index,
            quickcart: this.quickcart,
          }, this.player || this.photoviewer);
          if (this.quickcart) {
            this.openDetails();
          }
          else {
            window.location.href = this.product.platformProduct.onlineStoreUrl;
          }
          return true;
        } }, h("img", { class: "product", src: this.product.platformProduct.featuredImage.url, alt: this.product.platformProduct.title }), h("div", { class: "product-card-body" }, h("div", { class: "product-card-item-name" }, this.product.platformProduct.title), h("div", { class: "product-card-item-price" }, h("span", { class: "unit-price-label" }, this.getPrice(this.product.platformProduct.priceRangeV2))), h("div", { class: "ctacontainer" }, h("button", { tabindex: "0", class: "product-buy-now-button" }, "Shop Now"))))));
    }
    else {
      return (h(Host, null));
    }
  }
  getPrice(range) {
    let finalPrice = `${this.getCurrencySymbol(range.minVariantPrice.currencyCode)} ${range.minVariantPrice.amount}`;
    if (range.minVariantPrice.amount !== range.maxVariantPrice.amount) {
      finalPrice = `${this.getCurrencySymbol(range.minVariantPrice.currencyCode)} ${range.minVariantPrice.amount} - ${this.getCurrencySymbol(range.minVariantPrice.currencyCode)} ${range.maxVariantPrice.amount}`;
    }
    return finalPrice;
  }
  getCurrencySymbol(currency) {
    var currency_symbols = {
      'USD': '$',
      'EUR': '€',
      'CRC': '₡',
      'GBP': '£',
      'ILS': '₪',
      'INR': '₹',
      'JPY': '¥',
      'KRW': '₩',
      'NGN': '₦',
      'PHP': '₱',
      'PLN': 'zł',
      'PYG': '₲',
      'THB': '฿',
      'UAH': '₴',
      'VND': '₫', // Vietnamese Dong
    };
    if (currency_symbols[currency] !== undefined) {
      return currency_symbols[currency];
    }
  }
  openDetails() {
    var _a;
    // console.log('open overlay from product card');
    // this.player?.viewFullScreen();
    (_a = this.overlay) === null || _a === void 0 ? void 0 : _a.open(this.product, this.channel, this.player, this.photoviewer, this.trackevent);
  }
  closeDetails() {
    this.el.shadowRoot.getElementById('product-details-popup').style.height = "0%";
  }
  get el() { return this; }
  static get style() { return asProductCardCss; }
}, [1, "as-product-card", {
    "product": [8],
    "mode": [8],
    "overlay": [8],
    "channel": [8],
    "trackevent": [8],
    "player": [8],
    "photoviewer": [8],
    "index": [2]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["as-product-card"];
  components.forEach(tagName => { switch (tagName) {
    case "as-product-card":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, AsProductCard);
      }
      break;
  } });
}

export { AsProductCard as A, defineCustomElement as d };

//# sourceMappingURL=as-product-card2.js.map